<?php
/**
 * A filter for checking if the user has accepted the rules. This is mainly
 * used and done in registration process and should not be removed from your
 * application.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class RulesAcceptedFilter extends BaseFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance			An instance of this filter class
	 */
	public static final function createRulesAcceptedFilter () {
		// Get a new instance
		$filterInstance = new RulesAcceptedFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If this filter fails to operate
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get the "rules" value from request
		$rules = $requestInstance->getRequestElement('rules');

		// Was the "rules" value found in form? And is it set?
		if (is_null($rules)) {
			// Not found in form so stop processing here
			$requestInstance->requestIsValid(FALSE);

			// Add a message to the response
			$responseInstance->addFatalMessage('rules_unchecked');

			// Skip further processing
			throw new FilterChainException($this, self::EXCEPTION_FILTER_CHAIN_INTERCEPTED);
		} // END - if
	}
}

// [EOF]
?>
